import requests
import json
import os

from dotenv import load_dotenv


load_dotenv()


class SaveInformation: # TODO 아직 API 배포가 되지않아 테스트를 해봐야함.
    """
    정보를 저장하는 클래스

    :param api_key: api_key
    :return:
    """
    def __init__(self, api_key):
        self.api_key = api_key

    def statistics(self):
        """
        통계 정보 저장하는 함수

        :return: None
        """
        url = "https://ai.vazil.me/api/ai/point-statistics"
        body = {
            "edgeId": "test-edge-id",
            "modelId": "test-model-id",
            "orgId": "test-orgId",
            "projectId": "test-projectId",
            "result": "ok",
            "inferenceRate": 0.8343494534492493,
            "inferenceTime": 47
        }

        params = {"api_key": self.api_key}
        headers = {"Content-Type": "application/json"}

        try:
            response = requests.post(url, params=params, headers=headers, data=json.dumps(body)).json()
            if response["status"] != 201:
                print("Failed to save statistics information storage.")
            print("Your statistics information have been saved successfully.")
        except requests.exceptions.RequestException as e:
            print("Error occurred: ", e)

    def inference(self):
        """
        inference 정보 저장하는 함수

        :return: None
        """
        url = "https://ai.vazil.me/api/ai/inference/info"
        body = {
          "modelId": "ai-test-loso",
          "pointId": "web-test-loso",
          "result": {
            "predict": 0,
            "predicts": [],
            "processTime": 0.5811035633087158,
            "result": "test",
            "detections": {
              "boxes": [],
              "scores": [],
              "classes": []
            },
            "height": 1400,
            "width": 1800
          }
        }

        params = {"api_key": self.api_key}
        headers = {"Content-Type": "application/json"}

        try:
            response = requests.post(url, params=params, headers=headers, data=json.dumps(body)).json()
            if response["status"] != 200:
                print("Failed to save statistics information storage.")
            print("Your inference information have been saved successfully.")
        except requests.exceptions.RequestException as e:
            print("Error occurred: ", e)


if __name__ == "__main__":
    api_key = os.getenv("api_key")
    saver = SaveInformation(api_key)
    saver.inference()


import requests
import json
import os

from dotenv import load_dotenv

load_dotenv()


class DatasetUploader:
    """
    데이터셋을 업로드하는 클래스

    :param
        - project_id: 프로젝트 아이디
        - org_id: 조직 아이디
        - api_key: api key
    :return: None
    """
    def __init__(self, project_id, org_id, api_key):
        self.projectId = project_id
        self.orgId = org_id
        self.api_key = api_key
        self.url = "https://ai.vazil.me/api/ai/dataset"
        self.body = None

    def set_dataset_upload_body(self):
        # ** 수정 필요함 **
        self.body = {
            "projectId": self.projectId,  # p-rkxbu51xz4fs
            "orgId": self.orgId,  # 2f0e2dc9433c46b1b21f81fdc3258fe6
            "train": [],
            "valid": [],
            "test": [],
            "preprocessing": {
                "resize": "Stretch to",
                "width": 380,
                "height": 380,
                "grayscale": False
            },
            "augmentations": {
                "brightness": {
                    "enable": False,
                    "scaleFactor": 1,
                    "offset": 0
                },
                "rotation": {
                    "enable": False,
                    "angle": 0
                },
                "crop": {
                    "enable": False,
                    "cropRate": 0
                },
                "flip": {
                    "enable": False,
                    "flipType": "HORIZONTAL"
                }
            },
            "details": {
                "versionId": 0,
                "name": "111_dataset_2024. 7. 29.",
                "createdAt": "2022-11-16T10:38:00",
                "trainingType": "IMAGE_CLASSIFICATION"
            },
            "labelMap": {
                "1": {
                    "color": "#47c9ad",
                    "count": 30,
                    "num": 1
                },
                "2": {
                    "color": "#008a6c",
                    "count": 42,
                    "num": 0
                }
            },
            "createUser": {
                "id": 1,
                "name": "관리자",
                "email": "admin@vazilcompany.com",
                "avatar": None
            },
            "datasetType": "IMAGE"
        }

    def dataset_upload(self):
        try:
            self.set_dataset_upload_body()
            params = {"api_key": self.api_key}
            headers = {"Content-Type": "application/json"}

            response = requests.post(self.url, params=params, headers=headers, data=json.dumps(self.body)).json()
            if not response["status"]:
                print("Dataset has not been uploaded.")
            print("The dataset has been uploaded successfully.")
        except requests.exceptions.RequestException as e:
            print("Error occurred: ", e)
        except ValueError as e:
            print(f"ValueError: {e}")


if __name__ == "__main__":
    projectId = os.environ.get("projectId")
    orgId = os.environ.get("orgId")
    api_key = os.environ.get("api_key")

    uploader = DatasetUploader(projectId, orgId, api_key)
    uploader.dataset_upload()



import os
os.environ['TF_CPP_MIN_LOG_LEVEL'] = '2'

import requests
import zipfile
import base64
import tensorflow as tf

from pathlib import Path
from dotenv import load_dotenv


load_dotenv()


class ModelDownload:
    """
    모델 다운로드 클래스

    :param
        - key: 모델을 다운로드 받을 키
        - file_name: 설정할 파일 이름
        - remove_zip_file: 다운로드 받고 난후 zip 파일 삭제 여부
            - True: 삭제
            - False: 삭제 안함
    :return: None
    """
    def __init__(self, key, file_name, remove_zip_file):
        self.key = key
        self.file_name = file_name
        self.remove_zip_file = remove_zip_file
        self.model_download()

    @staticmethod
    def check_already_folder_exist():
        """
        download_folder 생성
        모델 다운로드 경로: download_folder
        """
        if not os.path.exists('./download_folder'):
            os.mkdir("./download_folder")
            print("download_folder has been created")
        else:
            print("download_folder already exist")
            print("The model was successfully downloaded.")

    @staticmethod
    # base64 파일을 .zip 파일로 변환
    def base64_convert_to_zipfile(file_name, base64_data):
        with open(f"download_folder/{file_name}.zip", "wb") as file:
            file.write(base64_data)

    def unzip(self):
        # 다운로드 받을 경로에 .zip 파일을 압축 해제
        target_folder = os.path.join('download_folder', self.file_name)
        zip_file_path = os.path.join('download_folder', f'{self.file_name}.zip')

        with zipfile.ZipFile(zip_file_path, 'r') as zip_ref:
            zip_ref.extractall(target_folder)

        # .zip 파일을 삭제하고 싶다면 remove_zip_flle = True,
        # 그렇지 않다면 False로 설정
        if self.remove_zip_file:
            os.remove(zip_file_path)

    def model_download(self):
        url = "https://ai.vazil.me/api/storage/file/download"
        params = {"key": self.key}

        """
        If you do not have a download path, create a download folder.
        download path: download_file/
        """
        self.check_already_folder_exist()

        try:
            response = requests.get(url, params=params)
            if response:
                base64_data = response.content
                self.base64_convert_to_zipfile(self.file_name, base64_data)
                self.unzip()
            print("The model was successfully downloaded.")
        except requests.exceptions.RequestException as e:
            print("Error occurred: ", e)
        except Exception as e:
            print(f"Error downloading the model: {e}")


class GroupModelCheck:
    """
    그룹 모델 확인하는 클래스

    :param
        - api_key: api key
        - id:
            projectId 또는 orgId

    for_organization: 조직 모델을 조회할 때
    for_project: 프로젝트 모델을 조회할 때

    :return: None
    """
    def __init__(self, api_key, id):
        self.api_key = api_key
        self.id = id

    @staticmethod
    def string_to_base64(key):
        # print(key)
        encoded_bytes = base64.b64encode(key.encode("utf-8"))
        encoded_string = encoded_bytes.decode("utf-8")
        # return encoded_string
        return "MmYwZTJkYzk0MzNjNDZiMWIyMWY4MWZkYzMyNThmZTYvbW9kZWxzL3RyYWluLXRvN3VrZWVmcDV3dy56aXA="

    def request(self, url, params):
        try:
            response = requests.get(url, params=params).json()
            if response["status"] != 200:
                print("Failed to query model.")
            # for item in response["body"]:
            #     print(item["key"])
            # key = response["body"][0]["key"]
            key = "2f0e2dc9433c46b1b21f81fdc3258fe6/models/train-to7ukeefp5ww.zip"
            return self.string_to_base64(key)
        except requests.exceptions.RequestException as e:
            print("Error occurred: ", e)

    def for_organization(self):
        url = "https://ai.vazil.me/api/ai/model/org"
        params = {"api_key": self.api_key, "orgId": self.id}
        return self.request(url, params)

    def for_project(self):
        url = "https://ai.vazil.me/api/ai/model/project"
        params = {"api_key": self.api_key, "projectId": self.id}
        return self.request(url, params)


class Model:
    """
    모델 로드 클래스

    :param
        - model_name: 다운로드 받을 때 설정한 이름
    """
    def __init__(self, model_name, project_folder_path):
        self.model_name = model_name
        self.download_folder_path = project_folder_path
        self.model = None

    def load(self):
        # Path(__file__).parent
        model_data_path = self.download_folder_path / "download_folder" / self.model_name
        self.model = tf.keras.models.load_model(model_data_path)

    def summary(self):
        self.model.summary()

    def inference(self, data):
        """
        data: 이미지 데이터 또는 모델에 맞는 데이터
            - 테스트를 진행 중 이라면 더미 데이터
        """
        count = 0
        for i in self.model.predict(data)[0]:
            print(f"{count} Accuracy: {i:.3f}")
            count += 1
        return self.model.predict(data)[0]


if __name__ == "__main__":
    api_key = "bf47a560-d8d2-411b-957b-1e8b3036369f"
    projectId = "p-rkxbu51xz4fs"
    orgId = "2f0e2dc9433c46b1b21f81fdc3258fe6"

    a = GroupModelCheck(api_key, projectId)
    key = a.for_project()

    file_name = 'model_version_2'

    ModelDownload(key, file_name, True)


import numpy as np
import tensorflow as tf
import base64

from io import BytesIO
from PIL import Image

import matplotlib.pyplot as plt


def image_to_byte(image):
    # 이미지를 바이트로 변환
    """
    이미지를 바이트로 변환하는 함수

    :param image: 이미지 파일 경로
    :return: 이미지를 바이트로 변환한 값
    """
    with Image.open(image) as image:
        buffered = BytesIO()
        image.save(buffered, format=image.format)
        img_str = base64.b64encode(buffered.getvalue()).decode()

    img_byte = base64.b64decode(img_str)
    img_byte = BytesIO(img_byte)
    img_byte = Image.open(img_byte)
    return img_byte


def show_image(image):
    """
    이미지를 받아 화면에 출력하는 함수

    :param image: 이미지 파일 경로
    :return: None
    """
    plt.figure(figsize=(6, 6))
    plt.imshow(image)
    plt.axis('off')
    plt.show()


def for_image(image):
    """
    이미지를 numpy 배열로 변환 후 반환하는 함수

    :param image: 이미지 파일 경로
    :return: 이미지를 numpy 배열로 반환 ( tensor )
    """
    img_byte = image_to_byte(image)

    img = tf.keras.preprocessing.image.img_to_array(img_byte)
    img_org = tf.cast(img, tf.uint8)

    height = img_org.shape[0]  # TODO 일단 패스.
    width = img_org.shape[1]

    img_org = tf.image.resize(img_org, [380, 380])

    channel = img_org.shape[2]
    if channel == 1:
        img_org = tf.convert_to_tensor(np.stack((np.reshape(img_org, (380, 380)),) * 3, axis=-1))
    elif channel == 4:
        img_org = tf.convert_to_tensor(img_org[:, :, :3])
    img_org = tf.dtypes.cast(img_org, dtype=tf.uint8)
    tensor = tf.expand_dims(img_org, axis=0)

    return tensor


if __name__ == "__main__":
    image = './vridgeai/data.jpg'
    data = for_image(image)
    print(data)


from setuptools import setup, find_packages

setup(
    name='vridge',
    version='0.0.1',
    description='vridge 파이썬 패키지',
    author='byungchan',
    author_email='bgk@vazilcompany.com',
    install_requires=['tensorflow==2.6.0',
                      'keras==2.6.0',
                      'protobuf==3.20.0',
                      'numpy==1.19.3',
                      'matplotlib==3.3.4',
                      'python-dotenv',
                      'requests'
                      ],
    packages=find_packages(exclude=[]),
    keywords=['vazil', 'vazilcompany', 'vridge', 'vridgeai'],
    python_requires='>=3.7, <3.10',
    package_data={},
    zip_safe=False,
    classifiers=[
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)
